@@ -4,7 +4,7 @@ use strict;
 
 use Carp;
 
-our $VERSION = '0.12';
+our $VERSION = '1.03';
 
 use overload
 (
@@ -12,8 +12,14 @@ use overload
    fallback => 1,
 );
 
-eval { require Time::HiRes };
-our $Have_HiRes_Time = $@ ? 0 : 1;
+our $Have_HiRes_Time;
+
+TRY:
+{
+  local $@;
+  eval { require Time::HiRes };
+  $Have_HiRes_Time = $@ ? 0 : 1;
+}
 
 # Allow an hour value of 24
 our $Allow_Hour_24 = 0;
@@ -192,9 +198,11 @@ sub format
   $format ||= ref($self)->default_format;
 
   my $hour  = $self->hour;
-  my $ihour = $hour > 12 ? ($hour - 12) : $hour;
+  my $ihour = $hour > 12 ? ($hour - 12) : $hour == 0 ? 12 : $hour;
   my $ns     = $self->nanosecond;
 
+  $ihour =~ s/^0//;
+
   my %formats =
   (
     'H' => sprintf('%02d', $hour),
@@ -243,7 +251,7 @@ sub parse
   if(my($hour, $min, $sec, $fsec, $ampm) = ($time =~ 
   m{^
       (\d\d?) # hour
-      (?::(\d\d)(?::(\d\d))?)?(?:\.(\d{0,9}))? # min? sec? nanosec?
+      (?::(\d\d)(?::(\d\d))?)?(?:\.(\d{0,9})\d*)? # min? sec? nanosec?
       (?:\s*([aApP]\.?[mM]\.?))? # am/pm
     $
   }x))
@@ -334,10 +342,10 @@ sub parse_delta
 
     if(my($hour, $min, $sec, $fsec) = ($delta =~ 
     m{^
-        (\d+)            # hours
-        (?::(\d+))?      # minutes
-        (?::(\d+))?      # seconds
-        (?:\.(\d{0,9}))? # nanoseconds
+        (\d+)               # hours
+        (?::(\d+))?         # minutes
+        (?::(\d+))?         # seconds
+        (?:\.(\d{0,9})\d*)? # nanoseconds
       $
     }x))
     {
@@ -703,7 +711,9 @@ Get or set the nanosecond of the clock.  INT must be an integer from 0 to 999999
 
 =item B<parse STRING>
 
-Set the clock time by parsing STRING.  Valid string values contain an hour with optional minutes, seconds, fractional seconds, and AM/PM string.  There should be a colon (":") between hours, minutes, and seconds, and a decimal point (".") between the seconds and fractional seconds.  Fractional seconds may contain up to 9 digits.  The AM/PM string is case-insensitive and may have periods after each letter.
+Set the clock time by parsing STRING.  The invoking object is returned.
+
+Valid string values contain an hour with optional minutes, seconds, fractional seconds, and AM/PM string.  There should be a colon (":") between hours, minutes, and seconds, and a decimal point (".") between the seconds and fractional seconds.  Fractional seconds may contain up to 9 digits.  The AM/PM string is case-insensitive and may have periods after each letter.
 
 The string "now" will initialize the clock object with the current (local) time.  If the L<Time::HiRes> module is installed, this time will have fractional seconds.
 
@@ -754,8 +764,8 @@ If the amount of time subtracted is large enough, the clock will wrap around fro
 
 John C. Siracusa (siracusa@gmail.com)
 
-=head1 COPYRIGHT
+=head1 LICENSE
 
-Copyright (c) 2006 by John C. Siracusa.  All rights reserved.  This program is
+Copyright (c) 2010 by John C. Siracusa.  All rights reserved.  This program is
 free software; you can redistribute it and/or modify it under the same terms
 as Perl itself.
